Learn R Programming

PReMiuM (version 3.1.2)

is.wholenumber: Function to check if a number is a whole number

Description

Function to check if a number is whole, accounting for a rounding error.

Usage

is.wholenumber(x, tol = .Machine$double.eps^0.5)

Arguments

x
The number to be checked.
tol
Tolerance level.

Value

  • The default method for 'is.wholenumber' returns 'TRUE' if the number provided is a whole number.

Authors

David Hastie, Department of Epidemiology and Biostatistics, Imperial College London, UK

Silvia Liverani, Department of Epidemiology and Biostatistics, Imperial College London and MRC Biostatistics Unit, Cambridge, UK

Maintainer: Silvia Liverani

References

Silvia Liverani, David I. Hastie, Lamiae Azizi, Michail Papathomas, Sylvia Richardson (2015). PReMiuM: An R Package for Profile Regression Mixture Models Using Dirichlet Processes. Journal of Statistical Software, 64(7), 1-30. URL http://www.jstatsoft.org/v64/i07/.

Examples

Run this code
is.wholenumber(4) # TRUE
is.wholenumber(3.4) # FALSE

Run the code above in your browser using DataLab